@@ -1,3 +1,4 @@
+# ruff: noqa: PLC0415
 import sys
 from collections.abc import Callable, Set
 from datetime import date, datetime, timezone
@@ -156,36 +157,38 @@ def everythings(
     ints = integers(min_value=min_int, max_value=max_int)
 
     return Everything(
-        draw(strings),
-        draw(binary()),
-        draw(ints),
-        draw(fs),
-        draw(dictionaries(key_text, ints)),
-        draw(dictionaries(key_text, strings)),
-        draw(lists(ints)),
-        tuple(draw(lists(ints))),
-        (draw(strings), draw(ints), draw(fs)),
-        Counter(draw(dictionaries(key_text, ints))),
-        draw(dictionaries(ints, fs)),
-        draw(dictionaries(fs, strings)),
-        draw(lists(fs)),
-        draw(lists(strings)),
-        draw(sets(fs)),
-        draw(sets(ints)),
-        draw(frozensets(strings)),
-        Everything.AnIntEnum.A,
-        Everything.AStringEnum.A,
-        Everything.ABareEnum.B,
-        draw(dts),
-        draw(dates(min_value=date(1970, 1, 1), max_value=date(2038, 1, 1))),
-        draw(dictionaries(just(Everything.AStringEnum.A), ints)),
-        draw(dictionaries(binary(min_size=min_key_length), binary())),
-        draw(one_of(ints, fs, strings)),
-        draw(one_of(ints, strings, sets(strings))),
-        draw(one_of(ints, strings, ints.map(A), strings.map(B))),
-        draw(fs.map(C)),
-        draw(one_of(just(1), just(Everything.AStringEnum.A))),
-        draw(one_of(just(1), just(Everything.ABareEnum.B))),
+        string=draw(strings),
+        bytes=draw(binary()),
+        an_int=draw(ints),
+        a_float=draw(fs),
+        a_dict=draw(dictionaries(key_text, ints)),
+        a_bare_dict=draw(dictionaries(key_text, strings)),
+        a_list=draw(lists(ints)),
+        a_homogenous_tuple=draw(lists(ints).map(tuple)),
+        a_hetero_tuple=(draw(strings), draw(ints), draw(fs)),
+        a_counter=Counter(draw(dictionaries(key_text, ints))),
+        a_mapping=draw(dictionaries(ints, fs)),
+        a_mutable_mapping=draw(dictionaries(fs, strings)),
+        a_sequence=draw(lists(fs).map(tuple)),
+        a_mutable_sequence=draw(lists(strings)),
+        a_set=draw(sets(fs)),
+        a_mutable_set=draw(sets(ints)),
+        a_frozenset=draw(frozensets(strings)),
+        an_int_enum=Everything.AnIntEnum.A,
+        a_str_enum=Everything.AStringEnum.A,
+        a_bare_enum=Everything.ABareEnum.B,
+        a_datetime=draw(dts),
+        a_date=draw(dates(min_value=date(1970, 1, 1), max_value=date(2038, 1, 1))),
+        a_string_enum_dict=draw(dictionaries(just(Everything.AStringEnum.A), ints)),
+        a_bytes_dict=draw(dictionaries(binary(min_size=min_key_length), binary())),
+        native_union=draw(one_of(ints, fs, strings)),
+        native_union_with_spillover=draw(one_of(ints, strings, sets(strings))),
+        native_union_with_union_spillover=draw(
+            one_of(ints, strings, ints.map(A), strings.map(B))
+        ),
+        a_namedtuple=draw(fs.map(C)),
+        a_literal=draw(one_of(just(1), just(Everything.AStringEnum.A))),
+        a_literal_with_bare=draw(one_of(just(1), just(Everything.ABareEnum.B))),
     )
 
 
